#!/bin/bash
#############################
# House keep 
#############################

sudo python /opt/tandbergtv/cms/cronjob/HouseKeeper.pyc